// Copyright (c) 2024 The Bitcoin developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.

import { UNSAFE_INTEGER_STRING } from 'wallet/fixtures/vectors';
export default {
    decimalizedTokenQtyToLocaleFormat: {
        expectedReturns: [
            {
                description: '9-decimal token',
                decimalizedTokenQty: '100.123456789',
                userLocale: 'en-US',
                returned: '100.123456789',
            },
            {
                description: 'Max possible eToken qty',
                decimalizedTokenQty: UNSAFE_INTEGER_STRING,
                userLocale: 'en-US',
                returned: '10,000,000,000,000,000',
            },
            {
                description: 'Max possible eToken qty with decimals',
                decimalizedTokenQty: `${UNSAFE_INTEGER_STRING}.123456789`,
                userLocale: 'en-US',
                returned: '10,000,000,000,000,000.123456789',
            },
            {
                description:
                    'One less than max possible eToken qty with decimals',
                decimalizedTokenQty: '9999999999999999.999999999',
                userLocale: 'en-US',
                returned: '9,999,999,999,999,999.999999999',
            },
            {
                description: 'A pretty normal token quantity',
                decimalizedTokenQty: '1000',
                userLocale: 'en-US',
                returned: '1,000',
            },
            {
                description: 'Smallest possible eToken quantity',
                decimalizedTokenQty: '0.000000001',
                userLocale: 'en-US',
                returned: '0.000000001',
            },
            {
                description: 'Smallest possible eToken quantity, but French',
                decimalizedTokenQty: '0.000000001',
                userLocale: 'fr-FR',
                returned: '0,000000001',
            },
            {
                description:
                    'One less than max possible eToken qty with decimals, but french',
                decimalizedTokenQty: '9999999999999999.999999999',
                userLocale: 'fr-FR',
                returned: '9 999 999 999 999 999,999999999',
            },
            {
                description: 'Locale with no thousands separator',
                decimalizedTokenQty: '6499969.00',
                userLocale: 'es-ES',
                returned: '6499969,00',
            },
            {
                description:
                    'Locale with multibyte thousands separator works as this is still string length 1',
                decimalizedTokenQty: '1000',
                userLocale: 'ar-AE',
                returned: '1,000',
            },
            {
                description:
                    'Locale with multibyte thousands separator works as this is still string length 1',
                decimalizedTokenQty: '1000',
                userLocale: 'ar',
                returned: '1٬000',
            },
            {
                description: 'NFT group mint with no decimals and de-DE locale',
                decimalizedTokenQty: '100',
                userLocale: 'de-DE',
                returned: '100',
            },
        ],
    },
    toFormattedXec: {
        expectedReturns: [
            {
                description: 'Balance over 1 trillion XEC (10 trillion)',
                satoshis: 1000000000000000,
                userLocale: 'en-US',
                returned: '10T',
            },
            {
                description: 'Balance of exactly 1 trillion XEC',
                satoshis: 100000000000000,
                userLocale: 'en-US',
                returned: '1T',
            },
            {
                description: 'Balance exceeding 1 billion XEC (10 billion)',
                satoshis: 1000000000000,
                userLocale: 'en-US',
                returned: '10B',
            },
            {
                description: 'Balance exactly 1 billion XEC',
                satoshis: 100000000000,
                userLocale: 'en-US',
                returned: '1B',
            },
            {
                description: 'Balance exceeding 1 million XEC (10 million)',
                satoshis: 1000000000,
                userLocale: 'en-US',
                returned: '10M',
            },
            {
                description: 'Balance of exactly 1 million XEC',
                satoshis: 100000000,
                userLocale: 'en-US',
                returned: '1M',
            },
            {
                description: 'Balance exceeding 1 thousand XEC (10 thousand)',
                satoshis: 1000000,
                userLocale: 'en-US',
                returned: '10k',
            },
            {
                description: 'Balance of exactly 1 thousand XEC',
                satoshis: 100000,
                userLocale: 'en-US',
                returned: '1k',
            },
            {
                description: 'Balance less than 1 thousand XEC',
                satoshis: 99999,
                userLocale: 'en-US',
                returned: '999.99',
            },
            {
                description: 'Balance less than 1 thousand XEC, but french',
                satoshis: 99999,
                userLocale: 'fr-FR',
                returned: '999,99',
            },
            {
                description: 'Balance less than 1 thousand XEC, but arabic',
                satoshis: 99999,
                userLocale: 'ar',
                returned: '٩٩٩٫٩٩',
            },
        ],
    },
    getFormattedFiatPrice: {
        expectedReturns: [
            {
                description: 'Fiat price > 1',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 100000,
                fiatPrice: 0.000033,
                returned: '$3.30 USD',
            },
            {
                description: 'Fiat price > 0.1 and < 1',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 10000,
                fiatPrice: 0.000033,
                returned: '$0.33 USD',
            },
            {
                description: 'Fiat price > 0.01 and < 0.1',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1000,
                fiatPrice: 0.000033,
                returned: '$0.033 USD',
            },
            {
                description: 'Fiat price > 0.001 and < 0.01',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 100,
                fiatPrice: 0.000033,
                returned: '$0.0033 USD',
            },
            {
                description: 'Fiat price > 0.00001 and < 0.0001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 10,
                fiatPrice: 0.000033,
                returned: '$0.00033 USD',
            },
            {
                description: 'Fiat price > 0.000001 and < 0.00001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1,
                fiatPrice: 0.000033,
                returned: '$0.000033 USD',
            },
            {
                description: 'Fiat price > 0.0000001 and < 0.000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.1,
                fiatPrice: 0.000033,
                returned: '$0.0000033 USD',
            },
            {
                description: 'Fiat price > 0.00000001 and < 0.0000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.01,
                fiatPrice: 0.000033,
                returned: '$0.00000033 USD',
            },
            {
                description: 'Fiat price > 0.000000001 and < 0.00000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.001,
                fiatPrice: 0.000033,
                returned: '$0.000000033 USD',
            },
            {
                description: 'Fiat price > 0.0000000001 and < 0.000000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.0001,
                fiatPrice: 0.000033,
                returned: '$0.0000000033 USD',
            },
            {
                description: 'Fiat price > 0.00000000001 and < 0.0000000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.00001,
                fiatPrice: 0.000033,
                returned: '$0.00000000033 USD',
            },
            {
                description: 'Lowest possible fiat price',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1e-11, // 1 nanosat,
                fiatPrice: 1,
                returned: '$0.0000000000100 USD',
            },
            {
                description:
                    'Fiat price > 0.0000000001 and < 0.000000001 and alt currency',
                settings: { fiatCurrency: 'gbp' },
                userLocale: 'en-US',
                priceXec: 0.0001,
                fiatPrice: 0.000033,
                returned: '£0.0000000033 GBP',
            },
            {
                description:
                    'Fiat price > 0.0000000001 and < 0.000000001 and alt currency and non-decimal locale',
                settings: { fiatCurrency: 'jpy' },
                userLocale: 'ar',
                priceXec: 0.0001,
                fiatPrice: 0.000033,
                // looks like ٠٫٠٠٠٠٠٠٠٠٣٣ JP¥ JPY but I can't get the unicode right
                returned: `${new Intl.NumberFormat('ar', {
                    style: 'currency',
                    currency: 'JPY',
                    minimumFractionDigits: 10,
                    maximumFractionDigits: 10,
                }).format(0.0001 * 0.000033)} JPY`,
            },
            {
                description: 'Smallest possible XEC price at a low fiat price',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1e-11, // 1 nanosat,
                fiatPrice: 0.000033,
                returned: '$0.00000000000000033 USD',
            },
            {
                description:
                    'Smallest possible XEC price at an even lower fiat price',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1e-11, // 1 nanosat,
                fiatPrice: 0.0000033,
                returned: '$0.000000000000000033 USD',
            },
            {
                description:
                    'Smallest possible XEC price at a lower still fiat price',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1e-11, // 1 nanosat,
                fiatPrice: 0.00000033,
                returned: '$0.0000000000000000033 USD',
            },
            {
                description: 'A fiat price too low to reasonably render',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1e-11, // 1 nanosat,
                fiatPrice: 0.00000000033,
                returned: '$0.00000000000000000000 USD',
            },
            {
                description: 'Price with problems in component testing',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1.101e-8,
                fiatPrice: 0.00003299,
                returned: '$0.00000000000036 USD',
            },
            {
                description: 'XEC price > 1',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 100,
                fiatPrice: null,
                returned: '100.00 XEC',
            },
            {
                description: 'XEC price > 0.1 and < 1',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.33,
                fiatPrice: null,
                returned: '0.33 XEC',
            },
            {
                description: 'XEC price > 0.01 and < 0.1',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.033,
                fiatPrice: null,
                returned: '0.033 XEC',
            },
            {
                description: 'XEC price > 0.001 and < 0.01',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.0033,
                fiatPrice: null,
                returned: '0.0033 XEC',
            },
            {
                description: 'XEC price > 0.00001 and < 0.0001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.00033,
                fiatPrice: null,
                returned: '0.00033 XEC',
            },
            {
                description: 'XEC price > 0.000001 and < 0.00001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.000033,
                fiatPrice: null,
                returned: '0.000033 XEC',
            },
            {
                description: 'XEC price > 0.0000001 and < 0.000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.0000033,
                fiatPrice: null,
                returned: '0.0000033 XEC',
            },
            {
                description: 'XEC price > 0.00000001 and < 0.0000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.00000033,
                fiatPrice: null,
                returned: '0.00000033 XEC',
            },
            {
                description: 'XEC price > 0.000000001 and < 0.00000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.000000033,
                fiatPrice: null,
                returned: '0.000000033 XEC',
            },
            {
                description: 'XEC price > 0.0000000001 and < 0.000000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.0000000033,
                fiatPrice: null,
                returned: '0.0000000033 XEC',
            },
            {
                description: 'XEC price > 0.00000000001 and < 0.0000000001',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 0.00000000033,
                fiatPrice: null,
                returned: '0.00000000033 XEC',
            },
            {
                description: 'Lowest possible XEC price',
                settings: { fiatCurrency: 'usd' },
                userLocale: 'en-US',
                priceXec: 1e-11, // 1 nanosat
                fiatPrice: null,
                returned: '0.0000000000100 XEC',
            },
        ],
    },
    getMinimumFractionDigits: {
        expectedReturns: [
            {
                description: 'Smallest supported price',
                number: 0.00000000000000000001,
                returned: 20,
            },
            {
                description:
                    'Going smaller, which would need 22 decimals to cover 2 precision digits, we still get 20',
                number: 0.000000000000000000001,
                returned: 20,
            },
            {
                description: 'Small number',
                number: 0.0000000000013,
                returned: 13,
            },
            {
                description: 'Small number with too much precision',
                number: 0.0000000000013456789,
                returned: 13,
            },
            {
                description: 'Normal decimal with too much precision',
                number: 0.123456789,
                returned: 2,
            },
            {
                description: 'Zero gets 2 decimal places',
                number: 0,
                returned: 2,
            },
            {
                description: 'One gets 2 decimal places',
                number: 1,
                returned: 2,
            },
            {
                description: 'Greater than one gets 2 decimal places',
                number: 123,
                returned: 2,
            },
        ],
    },
};
